<a class="nav-link dropdown-toggle d-none d-sm-inline-block" href="#"
   data-bs-toggle="dropdown">
    <span class="text-dark">{{ current_user.profile.surname }}, {{ current_user.profile.name }}</span>
</a>
